// SquidMainWindow.h: interface for the SquidMainWindow class.
//
//////////////////////////////////////////////////////////////////////

#ifndef SQUIDMAINWINDOW_H

#include <qmainwindow.h>
#include <qscrollview.h>
#include <qsplitter.h>
#include <qtoolbutton.h>
#include <qwmatrix.h>

#include "SquidPortrait.h"
#include "SquidStaticPane.h"
#include "SquidDynamicPane.h"
#include "SquidDiffBlocker.h"

#endif

class SquidMainWindow : public QMainWindow  
{
	Q_OBJECT
public:
	SquidMainWindow( QImage* file1, QImage* file2, QString n1, QString n2 );
	virtual ~SquidMainWindow();

	void resizeEvent( QResizeEvent* e );

	void InitToolBar();
	void SetMaxSize();

	void SetBGColor( QRgb col );
	QRgb BGColor() { return f1->scroll->viewport()->backgroundColor().rgb(); };
	int BlendSize() { return di->blendsize; };
	int DiffTol() { return dtolnc; };
	int MinBlock() { return minblocksize; };
	void SetBlendSize( int area );
	void SetDiffTol( int rms );
	void SetMinBlock( int min );

	void LoadSettings();

public slots:
	void dummy() { };
	void HScroll( int pct );
	void VScroll( int pct );
	void ToggleDiff( bool );
	void ToggleF1( bool );
	void ToggleF2( bool );
	void ToggleMask( bool mask ) { di->maskdiffs = mask; di->Redraw(); };
	void ZoomIn();
	void ZoomOut();
	void ToggleBlocks( bool blocks );
	void Prefs();
	void SaveSettings();
	void About();
private:
	SquidStaticPane *f1, *f2;
	SquidDynamicPane *di;
	SquidDiffBlocker *dblocks;

	QToolBar* toolbar;
	QToolButton *f1b, *f2b, *dib, *mask;
	QScrollBar *hscroll, *vscroll;
	QSplitter* sp;

	float zoom;
	int minblocksize;
	int dtolnc;
};
